#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class Dishes(object):

    def __init__(self):
        self._dish_id = None
        self._dish_name = None
        self._dish_num = None
        self._dish_price = None
        self._dish_real_price = None
        self._dish_skuid = None

    @property
    def dish_id(self):
        return self._dish_id

    @dish_id.setter
    def dish_id(self, value):
        self._dish_id = value
    @property
    def dish_name(self):
        return self._dish_name

    @dish_name.setter
    def dish_name(self, value):
        self._dish_name = value
    @property
    def dish_num(self):
        return self._dish_num

    @dish_num.setter
    def dish_num(self, value):
        self._dish_num = value
    @property
    def dish_price(self):
        return self._dish_price

    @dish_price.setter
    def dish_price(self, value):
        self._dish_price = value
    @property
    def dish_real_price(self):
        return self._dish_real_price

    @dish_real_price.setter
    def dish_real_price(self, value):
        self._dish_real_price = value
    @property
    def dish_skuid(self):
        return self._dish_skuid

    @dish_skuid.setter
    def dish_skuid(self, value):
        self._dish_skuid = value


    def to_alipay_dict(self):
        params = dict()
        if self.dish_id:
            if hasattr(self.dish_id, 'to_alipay_dict'):
                params['dish_id'] = self.dish_id.to_alipay_dict()
            else:
                params['dish_id'] = self.dish_id
        if self.dish_name:
            if hasattr(self.dish_name, 'to_alipay_dict'):
                params['dish_name'] = self.dish_name.to_alipay_dict()
            else:
                params['dish_name'] = self.dish_name
        if self.dish_num:
            if hasattr(self.dish_num, 'to_alipay_dict'):
                params['dish_num'] = self.dish_num.to_alipay_dict()
            else:
                params['dish_num'] = self.dish_num
        if self.dish_price:
            if hasattr(self.dish_price, 'to_alipay_dict'):
                params['dish_price'] = self.dish_price.to_alipay_dict()
            else:
                params['dish_price'] = self.dish_price
        if self.dish_real_price:
            if hasattr(self.dish_real_price, 'to_alipay_dict'):
                params['dish_real_price'] = self.dish_real_price.to_alipay_dict()
            else:
                params['dish_real_price'] = self.dish_real_price
        if self.dish_skuid:
            if hasattr(self.dish_skuid, 'to_alipay_dict'):
                params['dish_skuid'] = self.dish_skuid.to_alipay_dict()
            else:
                params['dish_skuid'] = self.dish_skuid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = Dishes()
        if 'dish_id' in d:
            o.dish_id = d['dish_id']
        if 'dish_name' in d:
            o.dish_name = d['dish_name']
        if 'dish_num' in d:
            o.dish_num = d['dish_num']
        if 'dish_price' in d:
            o.dish_price = d['dish_price']
        if 'dish_real_price' in d:
            o.dish_real_price = d['dish_real_price']
        if 'dish_skuid' in d:
            o.dish_skuid = d['dish_skuid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.Product import Product
from alipay.aop.api.domain.Sale import Sale


class AlipayEcoMycarFuellingShopQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoMycarFuellingShopQueryResponse, self).__init__()
        self._address = None
        self._city_code = None
        self._district_code = None
        self._lat = None
        self._lon = None
        self._out_shop_id = None
        self._pay_url = None
        self._poi_id = None
        self._product = None
        self._province_code = None
        self._sale = None
        self._shop_id = None
        self._shop_name = None
        self._shop_status = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def district_code(self):
        return self._district_code

    @district_code.setter
    def district_code(self, value):
        self._district_code = value
    @property
    def lat(self):
        return self._lat

    @lat.setter
    def lat(self, value):
        self._lat = value
    @property
    def lon(self):
        return self._lon

    @lon.setter
    def lon(self, value):
        self._lon = value
    @property
    def out_shop_id(self):
        return self._out_shop_id

    @out_shop_id.setter
    def out_shop_id(self, value):
        self._out_shop_id = value
    @property
    def pay_url(self):
        return self._pay_url

    @pay_url.setter
    def pay_url(self, value):
        self._pay_url = value
    @property
    def poi_id(self):
        return self._poi_id

    @poi_id.setter
    def poi_id(self, value):
        self._poi_id = value
    @property
    def product(self):
        return self._product

    @product.setter
    def product(self, value):
        if isinstance(value, list):
            self._product = list()
            for i in value:
                if isinstance(i, Product):
                    self._product.append(i)
                else:
                    self._product.append(Product.from_alipay_dict(i))
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def sale(self):
        return self._sale

    @sale.setter
    def sale(self, value):
        if isinstance(value, list):
            self._sale = list()
            for i in value:
                if isinstance(i, Sale):
                    self._sale.append(i)
                else:
                    self._sale.append(Sale.from_alipay_dict(i))
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def shop_status(self):
        return self._shop_status

    @shop_status.setter
    def shop_status(self, value):
        self._shop_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoMycarFuellingShopQueryResponse, self).parse_response_content(response_content)
        if 'address' in response:
            self.address = response['address']
        if 'city_code' in response:
            self.city_code = response['city_code']
        if 'district_code' in response:
            self.district_code = response['district_code']
        if 'lat' in response:
            self.lat = response['lat']
        if 'lon' in response:
            self.lon = response['lon']
        if 'out_shop_id' in response:
            self.out_shop_id = response['out_shop_id']
        if 'pay_url' in response:
            self.pay_url = response['pay_url']
        if 'poi_id' in response:
            self.poi_id = response['poi_id']
        if 'product' in response:
            self.product = response['product']
        if 'province_code' in response:
            self.province_code = response['province_code']
        if 'sale' in response:
            self.sale = response['sale']
        if 'shop_id' in response:
            self.shop_id = response['shop_id']
        if 'shop_name' in response:
            self.shop_name = response['shop_name']
        if 'shop_status' in response:
            self.shop_status = response['shop_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AccessReturnQrcode import AccessReturnQrcode


class KoubeiSalesKbassetStuffQrcodereturnSyncModel(object):

    def __init__(self):
        self._return_qrcodes = None

    @property
    def return_qrcodes(self):
        return self._return_qrcodes

    @return_qrcodes.setter
    def return_qrcodes(self, value):
        if isinstance(value, list):
            self._return_qrcodes = list()
            for i in value:
                if isinstance(i, AccessReturnQrcode):
                    self._return_qrcodes.append(i)
                else:
                    self._return_qrcodes.append(AccessReturnQrcode.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.return_qrcodes:
            if isinstance(self.return_qrcodes, list):
                for i in range(0, len(self.return_qrcodes)):
                    element = self.return_qrcodes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.return_qrcodes[i] = element.to_alipay_dict()
            if hasattr(self.return_qrcodes, 'to_alipay_dict'):
                params['return_qrcodes'] = self.return_qrcodes.to_alipay_dict()
            else:
                params['return_qrcodes'] = self.return_qrcodes
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiSalesKbassetStuffQrcodereturnSyncModel()
        if 'return_qrcodes' in d:
            o.return_qrcodes = d['return_qrcodes']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DeviceApplyOrderItemDto(object):

    def __init__(self):
        self._apply_amount = None
        self._billed = None
        self._item_id = None
        self._item_name = None
        self._model_number = None
        self._selling_price = None
        self._sn_list = None
        self._supplier_id = None

    @property
    def apply_amount(self):
        return self._apply_amount

    @apply_amount.setter
    def apply_amount(self, value):
        self._apply_amount = value
    @property
    def billed(self):
        return self._billed

    @billed.setter
    def billed(self, value):
        self._billed = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def model_number(self):
        return self._model_number

    @model_number.setter
    def model_number(self, value):
        self._model_number = value
    @property
    def selling_price(self):
        return self._selling_price

    @selling_price.setter
    def selling_price(self, value):
        self._selling_price = value
    @property
    def sn_list(self):
        return self._sn_list

    @sn_list.setter
    def sn_list(self, value):
        if isinstance(value, list):
            self._sn_list = list()
            for i in value:
                self._sn_list.append(i)
    @property
    def supplier_id(self):
        return self._supplier_id

    @supplier_id.setter
    def supplier_id(self, value):
        self._supplier_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_amount:
            if hasattr(self.apply_amount, 'to_alipay_dict'):
                params['apply_amount'] = self.apply_amount.to_alipay_dict()
            else:
                params['apply_amount'] = self.apply_amount
        if self.billed:
            if hasattr(self.billed, 'to_alipay_dict'):
                params['billed'] = self.billed.to_alipay_dict()
            else:
                params['billed'] = self.billed
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.model_number:
            if hasattr(self.model_number, 'to_alipay_dict'):
                params['model_number'] = self.model_number.to_alipay_dict()
            else:
                params['model_number'] = self.model_number
        if self.selling_price:
            if hasattr(self.selling_price, 'to_alipay_dict'):
                params['selling_price'] = self.selling_price.to_alipay_dict()
            else:
                params['selling_price'] = self.selling_price
        if self.sn_list:
            if isinstance(self.sn_list, list):
                for i in range(0, len(self.sn_list)):
                    element = self.sn_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sn_list[i] = element.to_alipay_dict()
            if hasattr(self.sn_list, 'to_alipay_dict'):
                params['sn_list'] = self.sn_list.to_alipay_dict()
            else:
                params['sn_list'] = self.sn_list
        if self.supplier_id:
            if hasattr(self.supplier_id, 'to_alipay_dict'):
                params['supplier_id'] = self.supplier_id.to_alipay_dict()
            else:
                params['supplier_id'] = self.supplier_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeviceApplyOrderItemDto()
        if 'apply_amount' in d:
            o.apply_amount = d['apply_amount']
        if 'billed' in d:
            o.billed = d['billed']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'model_number' in d:
            o.model_number = d['model_number']
        if 'selling_price' in d:
            o.selling_price = d['selling_price']
        if 'sn_list' in d:
            o.sn_list = d['sn_list']
        if 'supplier_id' in d:
            o.supplier_id = d['supplier_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZolozAuthenticationCustomerFaceverifyMatchModel(object):

    def __init__(self):
        self._auth_img = None
        self._auth_img_channel = None
        self._biz_id = None
        self._cert_name = None
        self._cert_no = None
        self._cert_type = None
        self._merchant_uid = None
        self._ref_img = None
        self._type = None

    @property
    def auth_img(self):
        return self._auth_img

    @auth_img.setter
    def auth_img(self, value):
        self._auth_img = value
    @property
    def auth_img_channel(self):
        return self._auth_img_channel

    @auth_img_channel.setter
    def auth_img_channel(self, value):
        self._auth_img_channel = value
    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def cert_name(self):
        return self._cert_name

    @cert_name.setter
    def cert_name(self, value):
        self._cert_name = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def merchant_uid(self):
        return self._merchant_uid

    @merchant_uid.setter
    def merchant_uid(self, value):
        self._merchant_uid = value
    @property
    def ref_img(self):
        return self._ref_img

    @ref_img.setter
    def ref_img(self, value):
        self._ref_img = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_img:
            if hasattr(self.auth_img, 'to_alipay_dict'):
                params['auth_img'] = self.auth_img.to_alipay_dict()
            else:
                params['auth_img'] = self.auth_img
        if self.auth_img_channel:
            if hasattr(self.auth_img_channel, 'to_alipay_dict'):
                params['auth_img_channel'] = self.auth_img_channel.to_alipay_dict()
            else:
                params['auth_img_channel'] = self.auth_img_channel
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.cert_name:
            if hasattr(self.cert_name, 'to_alipay_dict'):
                params['cert_name'] = self.cert_name.to_alipay_dict()
            else:
                params['cert_name'] = self.cert_name
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.merchant_uid:
            if hasattr(self.merchant_uid, 'to_alipay_dict'):
                params['merchant_uid'] = self.merchant_uid.to_alipay_dict()
            else:
                params['merchant_uid'] = self.merchant_uid
        if self.ref_img:
            if hasattr(self.ref_img, 'to_alipay_dict'):
                params['ref_img'] = self.ref_img.to_alipay_dict()
            else:
                params['ref_img'] = self.ref_img
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZolozAuthenticationCustomerFaceverifyMatchModel()
        if 'auth_img' in d:
            o.auth_img = d['auth_img']
        if 'auth_img_channel' in d:
            o.auth_img_channel = d['auth_img_channel']
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'cert_name' in d:
            o.cert_name = d['cert_name']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'merchant_uid' in d:
            o.merchant_uid = d['merchant_uid']
        if 'ref_img' in d:
            o.ref_img = d['ref_img']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ActivityShopInfo(object):

    def __init__(self):
        self._latitude = None
        self._longitude = None
        self._shop_id = None
        self._shop_name = None
        self._shop_type = None

    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def shop_type(self):
        return self._shop_type

    @shop_type.setter
    def shop_type(self, value):
        self._shop_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.shop_type:
            if hasattr(self.shop_type, 'to_alipay_dict'):
                params['shop_type'] = self.shop_type.to_alipay_dict()
            else:
                params['shop_type'] = self.shop_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ActivityShopInfo()
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'shop_type' in d:
            o.shop_type = d['shop_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoney import MultiCurrencyMoney
from alipay.aop.api.domain.UserVo import UserVo


class MybankCreditLoantradeBillBudgetQueryModel(object):

    def __init__(self):
        self._apply_amount = None
        self._bill_no = None
        self._out_request_no = None
        self._product_code = None
        self._repay_budget_type = None
        self._user = None

    @property
    def apply_amount(self):
        return self._apply_amount

    @apply_amount.setter
    def apply_amount(self, value):
        if isinstance(value, MultiCurrencyMoney):
            self._apply_amount = value
        else:
            self._apply_amount = MultiCurrencyMoney.from_alipay_dict(value)
    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def repay_budget_type(self):
        return self._repay_budget_type

    @repay_budget_type.setter
    def repay_budget_type(self, value):
        self._repay_budget_type = value
    @property
    def user(self):
        return self._user

    @user.setter
    def user(self, value):
        if isinstance(value, UserVo):
            self._user = value
        else:
            self._user = UserVo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.apply_amount:
            if hasattr(self.apply_amount, 'to_alipay_dict'):
                params['apply_amount'] = self.apply_amount.to_alipay_dict()
            else:
                params['apply_amount'] = self.apply_amount
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.repay_budget_type:
            if hasattr(self.repay_budget_type, 'to_alipay_dict'):
                params['repay_budget_type'] = self.repay_budget_type.to_alipay_dict()
            else:
                params['repay_budget_type'] = self.repay_budget_type
        if self.user:
            if hasattr(self.user, 'to_alipay_dict'):
                params['user'] = self.user.to_alipay_dict()
            else:
                params['user'] = self.user
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditLoantradeBillBudgetQueryModel()
        if 'apply_amount' in d:
            o.apply_amount = d['apply_amount']
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'repay_budget_type' in d:
            o.repay_budget_type = d['repay_budget_type']
        if 'user' in d:
            o.user = d['user']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiQualityTestCloudacptCheckresultSubmitModel(object):

    def __init__(self):
        self._activity_id = None
        self._auth_code = None
        self._batch_id = None
        self._end_time = None
        self._pid = None
        self._start_time = None
        self._uid = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def auth_code(self):
        return self._auth_code

    @auth_code.setter
    def auth_code(self, value):
        self._auth_code = value
    @property
    def batch_id(self):
        return self._batch_id

    @batch_id.setter
    def batch_id(self, value):
        self._batch_id = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def uid(self):
        return self._uid

    @uid.setter
    def uid(self, value):
        self._uid = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.auth_code:
            if hasattr(self.auth_code, 'to_alipay_dict'):
                params['auth_code'] = self.auth_code.to_alipay_dict()
            else:
                params['auth_code'] = self.auth_code
        if self.batch_id:
            if hasattr(self.batch_id, 'to_alipay_dict'):
                params['batch_id'] = self.batch_id.to_alipay_dict()
            else:
                params['batch_id'] = self.batch_id
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.uid:
            if hasattr(self.uid, 'to_alipay_dict'):
                params['uid'] = self.uid.to_alipay_dict()
            else:
                params['uid'] = self.uid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiQualityTestCloudacptCheckresultSubmitModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'auth_code' in d:
            o.auth_code = d['auth_code']
        if 'batch_id' in d:
            o.batch_id = d['batch_id']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'pid' in d:
            o.pid = d['pid']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'uid' in d:
            o.uid = d['uid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundBailOrderMigrateModel(object):

    def __init__(self):
        self._agreement_no = None
        self._extra_param = None
        self._out_request_no = None
        self._product_code = None
        self._remark = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def extra_param(self):
        return self._extra_param

    @extra_param.setter
    def extra_param(self, value):
        self._extra_param = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.extra_param:
            if hasattr(self.extra_param, 'to_alipay_dict'):
                params['extra_param'] = self.extra_param.to_alipay_dict()
            else:
                params['extra_param'] = self.extra_param
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundBailOrderMigrateModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'extra_param' in d:
            o.extra_param = d['extra_param']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'remark' in d:
            o.remark = d['remark']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class YunTaskVoucherTemplateInfo(object):

    def __init__(self):
        self._template_id = None
        self._voucher_name = None

    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def voucher_name(self):
        return self._voucher_name

    @voucher_name.setter
    def voucher_name(self, value):
        self._voucher_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.voucher_name:
            if hasattr(self.voucher_name, 'to_alipay_dict'):
                params['voucher_name'] = self.voucher_name.to_alipay_dict()
            else:
                params['voucher_name'] = self.voucher_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = YunTaskVoucherTemplateInfo()
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'voucher_name' in d:
            o.voucher_name = d['voucher_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KbdishPropertyValueInfo import KbdishPropertyValueInfo


class KbdishPropertyInfo(object):

    def __init__(self):
        self._max_count_limit = None
        self._min_count_limit = None
        self._property_name = None
        self._property_value_info_list = None
        self._sort = None

    @property
    def max_count_limit(self):
        return self._max_count_limit

    @max_count_limit.setter
    def max_count_limit(self, value):
        self._max_count_limit = value
    @property
    def min_count_limit(self):
        return self._min_count_limit

    @min_count_limit.setter
    def min_count_limit(self, value):
        self._min_count_limit = value
    @property
    def property_name(self):
        return self._property_name

    @property_name.setter
    def property_name(self, value):
        self._property_name = value
    @property
    def property_value_info_list(self):
        return self._property_value_info_list

    @property_value_info_list.setter
    def property_value_info_list(self, value):
        if isinstance(value, list):
            self._property_value_info_list = list()
            for i in value:
                if isinstance(i, KbdishPropertyValueInfo):
                    self._property_value_info_list.append(i)
                else:
                    self._property_value_info_list.append(KbdishPropertyValueInfo.from_alipay_dict(i))
    @property
    def sort(self):
        return self._sort

    @sort.setter
    def sort(self, value):
        self._sort = value


    def to_alipay_dict(self):
        params = dict()
        if self.max_count_limit:
            if hasattr(self.max_count_limit, 'to_alipay_dict'):
                params['max_count_limit'] = self.max_count_limit.to_alipay_dict()
            else:
                params['max_count_limit'] = self.max_count_limit
        if self.min_count_limit:
            if hasattr(self.min_count_limit, 'to_alipay_dict'):
                params['min_count_limit'] = self.min_count_limit.to_alipay_dict()
            else:
                params['min_count_limit'] = self.min_count_limit
        if self.property_name:
            if hasattr(self.property_name, 'to_alipay_dict'):
                params['property_name'] = self.property_name.to_alipay_dict()
            else:
                params['property_name'] = self.property_name
        if self.property_value_info_list:
            if isinstance(self.property_value_info_list, list):
                for i in range(0, len(self.property_value_info_list)):
                    element = self.property_value_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.property_value_info_list[i] = element.to_alipay_dict()
            if hasattr(self.property_value_info_list, 'to_alipay_dict'):
                params['property_value_info_list'] = self.property_value_info_list.to_alipay_dict()
            else:
                params['property_value_info_list'] = self.property_value_info_list
        if self.sort:
            if hasattr(self.sort, 'to_alipay_dict'):
                params['sort'] = self.sort.to_alipay_dict()
            else:
                params['sort'] = self.sort
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbdishPropertyInfo()
        if 'max_count_limit' in d:
            o.max_count_limit = d['max_count_limit']
        if 'min_count_limit' in d:
            o.min_count_limit = d['min_count_limit']
        if 'property_name' in d:
            o.property_name = d['property_name']
        if 'property_value_info_list' in d:
            o.property_value_info_list = d['property_value_info_list']
        if 'sort' in d:
            o.sort = d['sort']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceIotMdeviceprodTradeBatchqueryModel(object):

    def __init__(self):
        self._device_sn = None
        self._item_id = None
        self._supplier_sn = None
        self._trade_no = None

    @property
    def device_sn(self):
        return self._device_sn

    @device_sn.setter
    def device_sn(self, value):
        self._device_sn = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def supplier_sn(self):
        return self._supplier_sn

    @supplier_sn.setter
    def supplier_sn(self, value):
        self._supplier_sn = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_sn:
            if hasattr(self.device_sn, 'to_alipay_dict'):
                params['device_sn'] = self.device_sn.to_alipay_dict()
            else:
                params['device_sn'] = self.device_sn
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.supplier_sn:
            if hasattr(self.supplier_sn, 'to_alipay_dict'):
                params['supplier_sn'] = self.supplier_sn.to_alipay_dict()
            else:
                params['supplier_sn'] = self.supplier_sn
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotMdeviceprodTradeBatchqueryModel()
        if 'device_sn' in d:
            o.device_sn = d['device_sn']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'supplier_sn' in d:
            o.supplier_sn = d['supplier_sn']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MobileDeviceInfo(object):

    def __init__(self):
        self._imei = None
        self._mobile_brand = None
        self._mobile_type = None

    @property
    def imei(self):
        return self._imei

    @imei.setter
    def imei(self, value):
        self._imei = value
    @property
    def mobile_brand(self):
        return self._mobile_brand

    @mobile_brand.setter
    def mobile_brand(self, value):
        self._mobile_brand = value
    @property
    def mobile_type(self):
        return self._mobile_type

    @mobile_type.setter
    def mobile_type(self, value):
        self._mobile_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.imei:
            if hasattr(self.imei, 'to_alipay_dict'):
                params['imei'] = self.imei.to_alipay_dict()
            else:
                params['imei'] = self.imei
        if self.mobile_brand:
            if hasattr(self.mobile_brand, 'to_alipay_dict'):
                params['mobile_brand'] = self.mobile_brand.to_alipay_dict()
            else:
                params['mobile_brand'] = self.mobile_brand
        if self.mobile_type:
            if hasattr(self.mobile_type, 'to_alipay_dict'):
                params['mobile_type'] = self.mobile_type.to_alipay_dict()
            else:
                params['mobile_type'] = self.mobile_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MobileDeviceInfo()
        if 'imei' in d:
            o.imei = d['imei']
        if 'mobile_brand' in d:
            o.mobile_brand = d['mobile_brand']
        if 'mobile_type' in d:
            o.mobile_type = d['mobile_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayAssetPointVoucherprodBenefittemplateCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayAssetPointVoucherprodBenefittemplateCreateResponse, self).__init__()
        self._asset_id = None
        self._bill_no = None

    @property
    def asset_id(self):
        return self._asset_id

    @asset_id.setter
    def asset_id(self, value):
        self._asset_id = value
    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayAssetPointVoucherprodBenefittemplateCreateResponse, self).parse_response_content(response_content)
        if 'asset_id' in response:
            self.asset_id = response['asset_id']
        if 'bill_no' in response:
            self.bill_no = response['bill_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniInnerbaseinfoApplogoUploadResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniInnerbaseinfoApplogoUploadResponse, self).__init__()
        self._app_logo = None

    @property
    def app_logo(self):
        return self._app_logo

    @app_logo.setter
    def app_logo(self, value):
        self._app_logo = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniInnerbaseinfoApplogoUploadResponse, self).parse_response_content(response_content)
        if 'app_logo' in response:
            self.app_logo = response['app_logo']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VoucherSendGuideModify(object):

    def __init__(self):
        self._voucher_detail_url = None

    @property
    def voucher_detail_url(self):
        return self._voucher_detail_url

    @voucher_detail_url.setter
    def voucher_detail_url(self, value):
        self._voucher_detail_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.voucher_detail_url:
            if hasattr(self.voucher_detail_url, 'to_alipay_dict'):
                params['voucher_detail_url'] = self.voucher_detail_url.to_alipay_dict()
            else:
                params['voucher_detail_url'] = self.voucher_detail_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherSendGuideModify()
        if 'voucher_detail_url' in d:
            o.voucher_detail_url = d['voucher_detail_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PaytoolRefundResultDetail import PaytoolRefundResultDetail


class AlipayBusinessOrderRefundQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBusinessOrderRefundQueryResponse, self).__init__()
        self._gmt_refund = None
        self._merchant_order_no = None
        self._order_no = None
        self._order_refund_amount = None
        self._refund_paytool_list = None

    @property
    def gmt_refund(self):
        return self._gmt_refund

    @gmt_refund.setter
    def gmt_refund(self, value):
        self._gmt_refund = value
    @property
    def merchant_order_no(self):
        return self._merchant_order_no

    @merchant_order_no.setter
    def merchant_order_no(self, value):
        self._merchant_order_no = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def order_refund_amount(self):
        return self._order_refund_amount

    @order_refund_amount.setter
    def order_refund_amount(self, value):
        self._order_refund_amount = value
    @property
    def refund_paytool_list(self):
        return self._refund_paytool_list

    @refund_paytool_list.setter
    def refund_paytool_list(self, value):
        if isinstance(value, list):
            self._refund_paytool_list = list()
            for i in value:
                if isinstance(i, PaytoolRefundResultDetail):
                    self._refund_paytool_list.append(i)
                else:
                    self._refund_paytool_list.append(PaytoolRefundResultDetail.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayBusinessOrderRefundQueryResponse, self).parse_response_content(response_content)
        if 'gmt_refund' in response:
            self.gmt_refund = response['gmt_refund']
        if 'merchant_order_no' in response:
            self.merchant_order_no = response['merchant_order_no']
        if 'order_no' in response:
            self.order_no = response['order_no']
        if 'order_refund_amount' in response:
            self.order_refund_amount = response['order_refund_amount']
        if 'refund_paytool_list' in response:
            self.refund_paytool_list = response['refund_paytool_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.RecruitItemApplyData import RecruitItemApplyData


class KoubeiMarketingCampaignRecruitApplyQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingCampaignRecruitApplyQueryResponse, self).__init__()
        self._bought_time = None
        self._end_time = None
        self._item_count = None
        self._item_info = None
        self._name = None
        self._prehot_time = None

    @property
    def bought_time(self):
        return self._bought_time

    @bought_time.setter
    def bought_time(self, value):
        self._bought_time = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def item_count(self):
        return self._item_count

    @item_count.setter
    def item_count(self, value):
        self._item_count = value
    @property
    def item_info(self):
        return self._item_info

    @item_info.setter
    def item_info(self, value):
        if isinstance(value, list):
            self._item_info = list()
            for i in value:
                if isinstance(i, RecruitItemApplyData):
                    self._item_info.append(i)
                else:
                    self._item_info.append(RecruitItemApplyData.from_alipay_dict(i))
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def prehot_time(self):
        return self._prehot_time

    @prehot_time.setter
    def prehot_time(self, value):
        self._prehot_time = value

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingCampaignRecruitApplyQueryResponse, self).parse_response_content(response_content)
        if 'bought_time' in response:
            self.bought_time = response['bought_time']
        if 'end_time' in response:
            self.end_time = response['end_time']
        if 'item_count' in response:
            self.item_count = response['item_count']
        if 'item_info' in response:
            self.item_info = response['item_info']
        if 'name' in response:
            self.name = response['name']
        if 'prehot_time' in response:
            self.prehot_time = response['prehot_time']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaMerchantOrderCreditQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaMerchantOrderCreditQueryResponse, self).__init__()
        self._channel = None
        self._cost = None
        self._credit_amount = None
        self._deposit = None
        self._finish_time = None
        self._fund_type = None
        self._merchant_id = None
        self._order_time = None
        self._out_order_no = None
        self._status = None
        self._zm_order_no = None

    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def cost(self):
        return self._cost

    @cost.setter
    def cost(self, value):
        self._cost = value
    @property
    def credit_amount(self):
        return self._credit_amount

    @credit_amount.setter
    def credit_amount(self, value):
        self._credit_amount = value
    @property
    def deposit(self):
        return self._deposit

    @deposit.setter
    def deposit(self, value):
        self._deposit = value
    @property
    def finish_time(self):
        return self._finish_time

    @finish_time.setter
    def finish_time(self, value):
        self._finish_time = value
    @property
    def fund_type(self):
        return self._fund_type

    @fund_type.setter
    def fund_type(self, value):
        self._fund_type = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def order_time(self):
        return self._order_time

    @order_time.setter
    def order_time(self, value):
        self._order_time = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def zm_order_no(self):
        return self._zm_order_no

    @zm_order_no.setter
    def zm_order_no(self, value):
        self._zm_order_no = value

    def parse_response_content(self, response_content):
        response = super(ZhimaMerchantOrderCreditQueryResponse, self).parse_response_content(response_content)
        if 'channel' in response:
            self.channel = response['channel']
        if 'cost' in response:
            self.cost = response['cost']
        if 'credit_amount' in response:
            self.credit_amount = response['credit_amount']
        if 'deposit' in response:
            self.deposit = response['deposit']
        if 'finish_time' in response:
            self.finish_time = response['finish_time']
        if 'fund_type' in response:
            self.fund_type = response['fund_type']
        if 'merchant_id' in response:
            self.merchant_id = response['merchant_id']
        if 'order_time' in response:
            self.order_time = response['order_time']
        if 'out_order_no' in response:
            self.out_order_no = response['out_order_no']
        if 'status' in response:
            self.status = response['status']
        if 'zm_order_no' in response:
            self.zm_order_no = response['zm_order_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MiniAppDeployResponse import MiniAppDeployResponse


class AlipayOpenMiniAppdeployBydeployversionQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniAppdeployBydeployversionQueryResponse, self).__init__()
        self._deploys = None

    @property
    def deploys(self):
        return self._deploys

    @deploys.setter
    def deploys(self, value):
        if isinstance(value, list):
            self._deploys = list()
            for i in value:
                if isinstance(i, MiniAppDeployResponse):
                    self._deploys.append(i)
                else:
                    self._deploys.append(MiniAppDeployResponse.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniAppdeployBydeployversionQueryResponse, self).parse_response_content(response_content)
        if 'deploys' in response:
            self.deploys = response['deploys']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.HomeApiResponse import HomeApiResponse


class AlipayIserviceItaskOrderRecordSyncResponse(AlipayResponse):

    def __init__(self):
        super(AlipayIserviceItaskOrderRecordSyncResponse, self).__init__()
        self._home_api_response = None

    @property
    def home_api_response(self):
        return self._home_api_response

    @home_api_response.setter
    def home_api_response(self, value):
        if isinstance(value, HomeApiResponse):
            self._home_api_response = value
        else:
            self._home_api_response = HomeApiResponse.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayIserviceItaskOrderRecordSyncResponse, self).parse_response_content(response_content)
        if 'home_api_response' in response:
            self.home_api_response = response['home_api_response']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SsdataDataserviceRiskAntifinfraudQueryModel(object):

    def __init__(self):
        self._apdid = None
        self._ip = None
        self._partner_id = None
        self._phone = None
        self._risk_code = None
        self._scene_code = None
        self._sys_version = None
        self._umid = None

    @property
    def apdid(self):
        return self._apdid

    @apdid.setter
    def apdid(self, value):
        self._apdid = value
    @property
    def ip(self):
        return self._ip

    @ip.setter
    def ip(self, value):
        self._ip = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def phone(self):
        return self._phone

    @phone.setter
    def phone(self, value):
        self._phone = value
    @property
    def risk_code(self):
        return self._risk_code

    @risk_code.setter
    def risk_code(self, value):
        self._risk_code = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def sys_version(self):
        return self._sys_version

    @sys_version.setter
    def sys_version(self, value):
        self._sys_version = value
    @property
    def umid(self):
        return self._umid

    @umid.setter
    def umid(self, value):
        self._umid = value


    def to_alipay_dict(self):
        params = dict()
        if self.apdid:
            if hasattr(self.apdid, 'to_alipay_dict'):
                params['apdid'] = self.apdid.to_alipay_dict()
            else:
                params['apdid'] = self.apdid
        if self.ip:
            if hasattr(self.ip, 'to_alipay_dict'):
                params['ip'] = self.ip.to_alipay_dict()
            else:
                params['ip'] = self.ip
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.phone:
            if hasattr(self.phone, 'to_alipay_dict'):
                params['phone'] = self.phone.to_alipay_dict()
            else:
                params['phone'] = self.phone
        if self.risk_code:
            if hasattr(self.risk_code, 'to_alipay_dict'):
                params['risk_code'] = self.risk_code.to_alipay_dict()
            else:
                params['risk_code'] = self.risk_code
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.sys_version:
            if hasattr(self.sys_version, 'to_alipay_dict'):
                params['sys_version'] = self.sys_version.to_alipay_dict()
            else:
                params['sys_version'] = self.sys_version
        if self.umid:
            if hasattr(self.umid, 'to_alipay_dict'):
                params['umid'] = self.umid.to_alipay_dict()
            else:
                params['umid'] = self.umid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SsdataDataserviceRiskAntifinfraudQueryModel()
        if 'apdid' in d:
            o.apdid = d['apdid']
        if 'ip' in d:
            o.ip = d['ip']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'phone' in d:
            o.phone = d['phone']
        if 'risk_code' in d:
            o.risk_code = d['risk_code']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'sys_version' in d:
            o.sys_version = d['sys_version']
        if 'umid' in d:
            o.umid = d['umid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ExtraInfo(object):

    def __init__(self):
        self._extra_info_key = None
        self._extra_info_value = None

    @property
    def extra_info_key(self):
        return self._extra_info_key

    @extra_info_key.setter
    def extra_info_key(self, value):
        self._extra_info_key = value
    @property
    def extra_info_value(self):
        return self._extra_info_value

    @extra_info_value.setter
    def extra_info_value(self, value):
        self._extra_info_value = value


    def to_alipay_dict(self):
        params = dict()
        if self.extra_info_key:
            if hasattr(self.extra_info_key, 'to_alipay_dict'):
                params['extra_info_key'] = self.extra_info_key.to_alipay_dict()
            else:
                params['extra_info_key'] = self.extra_info_key
        if self.extra_info_value:
            if hasattr(self.extra_info_value, 'to_alipay_dict'):
                params['extra_info_value'] = self.extra_info_value.to_alipay_dict()
            else:
                params['extra_info_value'] = self.extra_info_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ExtraInfo()
        if 'extra_info_key' in d:
            o.extra_info_key = d['extra_info_key']
        if 'extra_info_value' in d:
            o.extra_info_value = d['extra_info_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsSceneInsserviceprodSerprogressSyncModel(object):

    def __init__(self):
        self._ant_ser_contract_no = None
        self._ant_ser_prod_no = None
        self._biz_data = None
        self._change_time = None
        self._out_biz_no = None
        self._ser_biz_no = None
        self._ser_biz_type = None
        self._status = None

    @property
    def ant_ser_contract_no(self):
        return self._ant_ser_contract_no

    @ant_ser_contract_no.setter
    def ant_ser_contract_no(self, value):
        self._ant_ser_contract_no = value
    @property
    def ant_ser_prod_no(self):
        return self._ant_ser_prod_no

    @ant_ser_prod_no.setter
    def ant_ser_prod_no(self, value):
        self._ant_ser_prod_no = value
    @property
    def biz_data(self):
        return self._biz_data

    @biz_data.setter
    def biz_data(self, value):
        self._biz_data = value
    @property
    def change_time(self):
        return self._change_time

    @change_time.setter
    def change_time(self, value):
        self._change_time = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def ser_biz_no(self):
        return self._ser_biz_no

    @ser_biz_no.setter
    def ser_biz_no(self, value):
        self._ser_biz_no = value
    @property
    def ser_biz_type(self):
        return self._ser_biz_type

    @ser_biz_type.setter
    def ser_biz_type(self, value):
        self._ser_biz_type = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.ant_ser_contract_no:
            if hasattr(self.ant_ser_contract_no, 'to_alipay_dict'):
                params['ant_ser_contract_no'] = self.ant_ser_contract_no.to_alipay_dict()
            else:
                params['ant_ser_contract_no'] = self.ant_ser_contract_no
        if self.ant_ser_prod_no:
            if hasattr(self.ant_ser_prod_no, 'to_alipay_dict'):
                params['ant_ser_prod_no'] = self.ant_ser_prod_no.to_alipay_dict()
            else:
                params['ant_ser_prod_no'] = self.ant_ser_prod_no
        if self.biz_data:
            if hasattr(self.biz_data, 'to_alipay_dict'):
                params['biz_data'] = self.biz_data.to_alipay_dict()
            else:
                params['biz_data'] = self.biz_data
        if self.change_time:
            if hasattr(self.change_time, 'to_alipay_dict'):
                params['change_time'] = self.change_time.to_alipay_dict()
            else:
                params['change_time'] = self.change_time
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.ser_biz_no:
            if hasattr(self.ser_biz_no, 'to_alipay_dict'):
                params['ser_biz_no'] = self.ser_biz_no.to_alipay_dict()
            else:
                params['ser_biz_no'] = self.ser_biz_no
        if self.ser_biz_type:
            if hasattr(self.ser_biz_type, 'to_alipay_dict'):
                params['ser_biz_type'] = self.ser_biz_type.to_alipay_dict()
            else:
                params['ser_biz_type'] = self.ser_biz_type
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneInsserviceprodSerprogressSyncModel()
        if 'ant_ser_contract_no' in d:
            o.ant_ser_contract_no = d['ant_ser_contract_no']
        if 'ant_ser_prod_no' in d:
            o.ant_ser_prod_no = d['ant_ser_prod_no']
        if 'biz_data' in d:
            o.biz_data = d['biz_data']
        if 'change_time' in d:
            o.change_time = d['change_time']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'ser_biz_no' in d:
            o.ser_biz_no = d['ser_biz_no']
        if 'ser_biz_type' in d:
            o.ser_biz_type = d['ser_biz_type']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayIserviceCognitiveAswfDagQueryModel(object):

    def __init__(self):
        self._biz_id = None
        self._ctxs = None
        self._template_id = None
        self._trace_id = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def ctxs(self):
        return self._ctxs

    @ctxs.setter
    def ctxs(self, value):
        self._ctxs = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.ctxs:
            if hasattr(self.ctxs, 'to_alipay_dict'):
                params['ctxs'] = self.ctxs.to_alipay_dict()
            else:
                params['ctxs'] = self.ctxs
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.trace_id:
            if hasattr(self.trace_id, 'to_alipay_dict'):
                params['trace_id'] = self.trace_id.to_alipay_dict()
            else:
                params['trace_id'] = self.trace_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayIserviceCognitiveAswfDagQueryModel()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'ctxs' in d:
            o.ctxs = d['ctxs']
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'trace_id' in d:
            o.trace_id = d['trace_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.FriendVO import FriendVO


class AlipayCommerceSportsGamesFriendlistQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceSportsGamesFriendlistQueryResponse, self).__init__()
        self._friend_list = None
        self._self_open_id = None

    @property
    def friend_list(self):
        return self._friend_list

    @friend_list.setter
    def friend_list(self, value):
        if isinstance(value, list):
            self._friend_list = list()
            for i in value:
                if isinstance(i, FriendVO):
                    self._friend_list.append(i)
                else:
                    self._friend_list.append(FriendVO.from_alipay_dict(i))
    @property
    def self_open_id(self):
        return self._self_open_id

    @self_open_id.setter
    def self_open_id(self, value):
        self._self_open_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceSportsGamesFriendlistQueryResponse, self).parse_response_content(response_content)
        if 'friend_list' in response:
            self.friend_list = response['friend_list']
        if 'self_open_id' in response:
            self.self_open_id = response['self_open_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PointsExchangeInfo(object):

    def __init__(self):
        self._ids = None
        self._type = None

    @property
    def ids(self):
        return self._ids

    @ids.setter
    def ids(self, value):
        if isinstance(value, list):
            self._ids = list()
            for i in value:
                self._ids.append(i)
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.ids:
            if isinstance(self.ids, list):
                for i in range(0, len(self.ids)):
                    element = self.ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ids[i] = element.to_alipay_dict()
            if hasattr(self.ids, 'to_alipay_dict'):
                params['ids'] = self.ids.to_alipay_dict()
            else:
                params['ids'] = self.ids
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PointsExchangeInfo()
        if 'ids' in d:
            o.ids = d['ids']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.UserIdentity import UserIdentity
from alipay.aop.api.domain.UserIdentityExt import UserIdentityExt


class AlipayBusinessPaymenthubRefundModel(object):

    def __init__(self):
        self._payee = None
        self._payee_ext = None
        self._payment_id = None
        self._refund_amount = None
        self._refund_request_no = None
        self._remark = None

    @property
    def payee(self):
        return self._payee

    @payee.setter
    def payee(self, value):
        if isinstance(value, UserIdentity):
            self._payee = value
        else:
            self._payee = UserIdentity.from_alipay_dict(value)
    @property
    def payee_ext(self):
        return self._payee_ext

    @payee_ext.setter
    def payee_ext(self, value):
        if isinstance(value, UserIdentityExt):
            self._payee_ext = value
        else:
            self._payee_ext = UserIdentityExt.from_alipay_dict(value)
    @property
    def payment_id(self):
        return self._payment_id

    @payment_id.setter
    def payment_id(self, value):
        self._payment_id = value
    @property
    def refund_amount(self):
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, value):
        self._refund_amount = value
    @property
    def refund_request_no(self):
        return self._refund_request_no

    @refund_request_no.setter
    def refund_request_no(self, value):
        self._refund_request_no = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value


    def to_alipay_dict(self):
        params = dict()
        if self.payee:
            if hasattr(self.payee, 'to_alipay_dict'):
                params['payee'] = self.payee.to_alipay_dict()
            else:
                params['payee'] = self.payee
        if self.payee_ext:
            if hasattr(self.payee_ext, 'to_alipay_dict'):
                params['payee_ext'] = self.payee_ext.to_alipay_dict()
            else:
                params['payee_ext'] = self.payee_ext
        if self.payment_id:
            if hasattr(self.payment_id, 'to_alipay_dict'):
                params['payment_id'] = self.payment_id.to_alipay_dict()
            else:
                params['payment_id'] = self.payment_id
        if self.refund_amount:
            if hasattr(self.refund_amount, 'to_alipay_dict'):
                params['refund_amount'] = self.refund_amount.to_alipay_dict()
            else:
                params['refund_amount'] = self.refund_amount
        if self.refund_request_no:
            if hasattr(self.refund_request_no, 'to_alipay_dict'):
                params['refund_request_no'] = self.refund_request_no.to_alipay_dict()
            else:
                params['refund_request_no'] = self.refund_request_no
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBusinessPaymenthubRefundModel()
        if 'payee' in d:
            o.payee = d['payee']
        if 'payee_ext' in d:
            o.payee_ext = d['payee_ext']
        if 'payment_id' in d:
            o.payment_id = d['payment_id']
        if 'refund_amount' in d:
            o.refund_amount = d['refund_amount']
        if 'refund_request_no' in d:
            o.refund_request_no = d['refund_request_no']
        if 'remark' in d:
            o.remark = d['remark']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiCateringDishCookQueryModel(object):

    def __init__(self):
        self._cook_id = None
        self._cook_status = None
        self._detail_catetory_big_id = None
        self._detail_catetory_small_id = None
        self._detail_status = None
        self._dish_id = None
        self._merchant_id = None

    @property
    def cook_id(self):
        return self._cook_id

    @cook_id.setter
    def cook_id(self, value):
        self._cook_id = value
    @property
    def cook_status(self):
        return self._cook_status

    @cook_status.setter
    def cook_status(self, value):
        self._cook_status = value
    @property
    def detail_catetory_big_id(self):
        return self._detail_catetory_big_id

    @detail_catetory_big_id.setter
    def detail_catetory_big_id(self, value):
        self._detail_catetory_big_id = value
    @property
    def detail_catetory_small_id(self):
        return self._detail_catetory_small_id

    @detail_catetory_small_id.setter
    def detail_catetory_small_id(self, value):
        self._detail_catetory_small_id = value
    @property
    def detail_status(self):
        return self._detail_status

    @detail_status.setter
    def detail_status(self, value):
        self._detail_status = value
    @property
    def dish_id(self):
        return self._dish_id

    @dish_id.setter
    def dish_id(self, value):
        self._dish_id = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.cook_id:
            if hasattr(self.cook_id, 'to_alipay_dict'):
                params['cook_id'] = self.cook_id.to_alipay_dict()
            else:
                params['cook_id'] = self.cook_id
        if self.cook_status:
            if hasattr(self.cook_status, 'to_alipay_dict'):
                params['cook_status'] = self.cook_status.to_alipay_dict()
            else:
                params['cook_status'] = self.cook_status
        if self.detail_catetory_big_id:
            if hasattr(self.detail_catetory_big_id, 'to_alipay_dict'):
                params['detail_catetory_big_id'] = self.detail_catetory_big_id.to_alipay_dict()
            else:
                params['detail_catetory_big_id'] = self.detail_catetory_big_id
        if self.detail_catetory_small_id:
            if hasattr(self.detail_catetory_small_id, 'to_alipay_dict'):
                params['detail_catetory_small_id'] = self.detail_catetory_small_id.to_alipay_dict()
            else:
                params['detail_catetory_small_id'] = self.detail_catetory_small_id
        if self.detail_status:
            if hasattr(self.detail_status, 'to_alipay_dict'):
                params['detail_status'] = self.detail_status.to_alipay_dict()
            else:
                params['detail_status'] = self.detail_status
        if self.dish_id:
            if hasattr(self.dish_id, 'to_alipay_dict'):
                params['dish_id'] = self.dish_id.to_alipay_dict()
            else:
                params['dish_id'] = self.dish_id
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringDishCookQueryModel()
        if 'cook_id' in d:
            o.cook_id = d['cook_id']
        if 'cook_status' in d:
            o.cook_status = d['cook_status']
        if 'detail_catetory_big_id' in d:
            o.detail_catetory_big_id = d['detail_catetory_big_id']
        if 'detail_catetory_small_id' in d:
            o.detail_catetory_small_id = d['detail_catetory_small_id']
        if 'detail_status' in d:
            o.detail_status = d['detail_status']
        if 'dish_id' in d:
            o.dish_id = d['dish_id']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        return o


